#!/bin/bash

SCORD_REPO=$HOME/var/projects/scord/repo
CARGO_REPO=$HOME/var/projects/cargo/repo
VOLUMES=$HOME/var/projects/scord/cluster/volumes
USER=amiranda

if [ $# -eq 0 ]; then
  echo "ERROR: No arguments supplied"
  echo "Usage: $0 <scord|cargo>"
  exit 1
fi

case $1 in
  scord)
    docker run -ti --rm \
      -v $SCORD_REPO:/home/$USER/repo \
      -v $VOLUMES/scord_prefix:/scord_prefix \
      -v $VOLUMES/cargo_prefix:/cargo_prefix \
      slurm-docker-cluster-node:21.08.6 \
      gosu $USER bash -c "
          cd ~/repo \
          && source /etc/profile.d/modules.sh \
          && module load mpi \
          && cmake \
                --preset=rocky \
                -DCMAKE_BUILD_TYPE=Debug \
          && cmake \
                --build builds/rocky \
                -j 8 \
                --verbose \
                -t install
      "
    ;;
  cargo)
    docker run -ti --rm \
      -v $CARGO_REPO:/home/$USER/cargo/repo \
      -v $VOLUMES/cargo_prefix:/cargo_prefix \
      slurm-docker-cluster-node:21.08.6 \
      gosu $USER bash -c "cd ~/cargo/repo && cmake --preset=rocky -DCMAKE_BUILD_TYPE=Debug && cmake --build builds/rocky -j 8 -t install"
    ;;
esac
